pub struct ZeroRttPacket<'p> { /* private fields */ }Expand description
A structure enabling manipulation of on the wire packets
Implementations
Sourceimpl<'a> ZeroRttPacket<'a>
impl<'a> ZeroRttPacket<'a>
Sourcepub fn new<'p>(packet: &'p [u8]) -> Option<ZeroRttPacket<'p>>
pub fn new<'p>(packet: &'p [u8]) -> Option<ZeroRttPacket<'p>>
Constructs a new #name. If the provided buffer is less than the minimum required packet size, this will return None.
Sourcepub fn owned(packet: Vec<u8>) -> Option<ZeroRttPacket<'static>>
pub fn owned(packet: Vec<u8>) -> Option<ZeroRttPacket<'static>>
Constructs a new #name. If the provided buffer is less than the minimum required packet size, this will return None. With this constructor the #name will own its own data and the underlying buffer will be dropped when the #name is.
Sourcepub fn to_immutable<'p>(&'p self) -> ZeroRttPacket<'p>
pub fn to_immutable<'p>(&'p self) -> ZeroRttPacket<'p>
Maps from a #name to a #imm_name
Sourcepub fn consume_to_immutable(self) -> ZeroRttPacket<'a>
pub fn consume_to_immutable(self) -> ZeroRttPacket<'a>
Maps from a #name to a #imm_name while consuming the source
Sourcepub const fn minimum_packet_size() -> usize
pub const fn minimum_packet_size() -> usize
The minimum size (in bytes) a packet of this type can be. It’s based on the total size of the fixed-size fields.
Sourcepub fn packet_size(_packet: &ZeroRtt) -> usize
pub fn packet_size(_packet: &ZeroRtt) -> usize
The size (in bytes) of a #base_name instance when converted into a byte-array
Sourcepub fn get_header_form(&self) -> HeaderForm
pub fn get_header_form(&self) -> HeaderForm
Get the value of the {name} field
Sourcepub fn get_fixed_bit(&self) -> FixedBit
pub fn get_fixed_bit(&self) -> FixedBit
Get the value of the {name} field
Sourcepub fn get_long_packet_type(&self) -> LongPacketType
pub fn get_long_packet_type(&self) -> LongPacketType
Get the value of the {name} field
Sourcepub fn get_reserved(&self) -> u2
pub fn get_reserved(&self) -> u2
Get the reserved field. This field is always stored big-endian within the struct, but this accessor returns host order.
Sourcepub fn get_packet_number_len(&self) -> u2
pub fn get_packet_number_len(&self) -> u2
Get the packet_number_len field. This field is always stored big-endian within the struct, but this accessor returns host order.
Sourcepub fn get_version(&self) -> Version
pub fn get_version(&self) -> Version
Get the value of the {name} field
Sourcepub fn get_dest_id_len(&self) -> u8
pub fn get_dest_id_len(&self) -> u8
Get the dest_id_len field. This field is always stored big-endian within the struct, but this accessor returns host order.
Sourcepub fn get_dest_id_raw(&self) -> &[u8] ⓘ
pub fn get_dest_id_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_dest_id(&self) -> Vec<u8> ⓘ
pub fn get_dest_id(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)
Sourcepub fn get_src_id_len(&self) -> u8
pub fn get_src_id_len(&self) -> u8
Get the src_id_len field. This field is always stored big-endian within the struct, but this accessor returns host order.
Sourcepub fn get_src_id_raw(&self) -> &[u8] ⓘ
pub fn get_src_id_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_src_id(&self) -> Vec<u8> ⓘ
pub fn get_src_id(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)
Sourcepub fn get_length_raw(&self) -> &[u8] ⓘ
pub fn get_length_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_length(&self) -> Vec<u8> ⓘ
pub fn get_length(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)
Sourcepub fn get_packet_number_raw(&self) -> &[u8] ⓘ
pub fn get_packet_number_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_packet_number(&self) -> Vec<u8> ⓘ
pub fn get_packet_number(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)
Sourcepub fn get_frames_raw(&self) -> &[u8] ⓘ
pub fn get_frames_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_frames(&self) -> Vec<u8> ⓘ
pub fn get_frames(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)
Sourcepub fn get_remaining_raw(&self) -> &[u8] ⓘ
pub fn get_remaining_raw(&self) -> &[u8] ⓘ
Get the raw &u8 value of the {name} field, without copying
Sourcepub fn get_remaining(&self) -> Vec<u8> ⓘ
pub fn get_remaining(&self) -> Vec<u8> ⓘ
Get the value of the {name} field (copies contents)